@@ -5,7 +5,7 @@ from selenium.webdriver.common.by import By
 
 class setup_shortcuts:
     '''Shortcut functions for Selenium'''
-    def __init__(self, port=9222, wait_for=10, browser='chrome', executable_path='chromedriver', headless=False):
+    def __init__(self, port=9222, wait_for=10, browser='chrome', executable_path='chromedriver', headless=False, browser_version=None):
         self.browser_process_id = None
 
         try: # Check if Chrome is already started
@@ -35,10 +35,10 @@ class setup_shortcuts:
         options.debugger_address = f'127.0.0.1:{port}' # Must be 127.0.0.1 for undetected-chromedriver, not localhost
         if browser == 'uc':
             import undetected_chromedriver as uc
-            driver = uc.Chrome(options=options, use_subprocess=True)
+            driver = uc.Chrome(options=options, use_subprocess=True, driver_executable_path=executable_path, version_main=browser_version)
             os.kill(driver.browser_pid, 15) # undetected-chromedriver connects to the existing browser then starts a browser on a random port, this closes the random browser
         else:
-            driver = webdriver.Chrome(options=options)
+            driver = webdriver.Chrome(options=options, executable_path=executable_path)
         driver.implicitly_wait(wait_for) # Wait X seconds for element to load before raising error
         self.driver = driver
         self.wait_for = wait_for
